#
# spec file for package gnubg
#
# Copyright (c) 2022 SUSE LLC
# Copyright (c) 2003 Achim Mueller, Germany.
# Updated by Christopher Hofmann in 2010
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           gnubg
Version:        1.06.002
Release:        3.5
Summary:        Backgammon game with analysis tools and neural network AI
License:        GPL-3.0-or-later
Group:          Amusements/Games/Board/Other
URL:            http://www.gnubg.org
Source:         http://gnubg.org/media/sources/gnubg-release-%{version}-sources.tar.gz
Source1:        %{name}.desktop
BuildRequires:  autoconf
BuildRequires:  autoconf-archive
BuildRequires:  automake
BuildRequires:  bison
BuildRequires:  cairo-devel
BuildRequires:  flex
BuildRequires:  freetype2-devel
BuildRequires:  glibc-devel
BuildRequires:  glu-devel
BuildRequires:  gmp-devel
BuildRequires:  gtkglext-devel
BuildRequires:  libcanberra-gtk-devel
BuildRequires:  libcurl-devel
BuildRequires:  libpng-devel
BuildRequires:  libtool
BuildRequires:  pkgconfig
BuildRequires:  python3-devel
BuildRequires:  readline-devel
BuildRequires:  sqlite3-devel
BuildRequires:  update-desktop-files
BuildRequires:  pkgconfig(glib-2.0)
BuildRequires:  pkgconfig(gtk+-2.0)
Recommends:     %{name}-lang
Recommends:     gnubg-databases = %{version}
Recommends:     gnubg-doc = %{version}
Recommends:     gnubg-sounds = %{version}
Recommends:     python3-MySQL-python

%description
Program for playing and analysing backgammon positions, games and matches. It is
based on a neural network. It currently plays at about the level of a
championship flight tournament player. Depending on its parameters and its luck
in recent games, it rates from around 1900 to 2000 on FIBS, the First Internet
Backgammon Server -- at its strongest, it ranks in the top 5 of over 6000 rated
players there and is gradually improving.

%package databases
Summary:        Bearoff databases for gnubg
License:        GPL-3.0-or-later
Group:          Amusements/Games/Board/Other
Requires:       %{name} = %{version}
BuildArch:      noarch

%description databases
Precalculated GNU Backgammon bearoff databases - its intelligence. If you prefer
a stronger or weaker opponent calculate you own with tweaked parameters
according to the documentation.

%package sounds
Summary:        Sounds for gnubg
License:        GPL-3.0-or-later
Group:          Amusements/Games/Board/Other
Requires:       %{name} = %{version}
BuildArch:      noarch

%description sounds
Sounds for GNU Backgammon. See description of gnubg for more details.

%package doc
Summary:        Documentation for gnubg
License:        GFDL-1.3-only
Group:          Amusements/Games/Board/Other
BuildArch:      noarch

%description doc
Manual for GNU Backgammon. See description of gnubg for more details.

%lang_package

%prep
%setup -q gnubg
# if we have a glib-gettext.m4 installed in the system, we drop the
# local copy in gnubg. It certainly is older
if [ -f %{_datadir}/aclocal/glib-gettext.m4 ]; then
  rm m4/glib-gettext.m4
fi
# Replace ax_python_devel.m4 for compatibility with Python 3.10.
rm -f m4/ax_python_devel.m4
cp -a %{_datadir}/aclocal/ax_python_devel.m4 m4/

%build
autoreconf -fi
simd=no
%ifarch %{ix86} x86_64
simd=sse2
%endif
%configure --docdir=%{_docdir}/%{name} --enable-simd=$simd
%make_build

%install
%make_install

%suse_update_desktop_file -i %{name}

%find_lang %{name}

%files
%license COPYING
%doc NEWS README TODO
%{_bindir}/*
%{_mandir}/man?/%{name}*
%{_mandir}/man?/bearoffdump.*
%{_mandir}/man?/makebearoff.*
%{_mandir}/man?/makehyper.*
%{_mandir}/man?/makeweights.*
%{_datadir}/applications/gnubg.desktop
%{_datadir}/icons/hicolor/*/apps/gnubg.png
%{_datadir}/gnubg
%attr(755,-,root) %{_datadir}/gnubg/scripts/query_player.sh
%exclude %{_datadir}/gnubg/*.bd
%exclude %{_datadir}/gnubg/sounds
%{_docdir}/%{name}
%exclude %{_docdir}/%{name}/images
%exclude %{_docdir}/%{name}/gnubg.html
%exclude %{_docdir}/%{name}/allabout.html

%files databases
%{_datadir}/gnubg/*.bd

%files sounds
%{_datadir}/gnubg/sounds

%files doc
%doc %{_docdir}/%{name}/images
%doc %{_docdir}/%{name}/gnubg.html
%doc %{_docdir}/%{name}/allabout.html

%files lang -f %{name}.lang

%changelog
* Mon Jul  4 2022 Asterios Dramis <asterios.dramis@gmail.com>
- Fix build with python 3.10 (update m4/ax_python_devel.m4). Added
  autoconf-archive build requirement for this.
- Added new build requirements: cairo-devel, libcurl-devel and
  pkgconfig.
- Replaced libcanberra-devel build requirement with correct
  libcanberra-gtk-devel.
- Build databases, sounds and doc subpackages as noarch (fix
  rpmlint error).
- Removed SUSE_ASNEEDED=1 (not needed anymore).
- Removed support for old openSUSE versions and Fedora.
* Mon Feb  3 2020 Steve Kowalik <steven.kowalik@suse.com>
- Switch to depending on python3.
- Run spec-cleaner over the specfile.
* Thu Aug 16 2018 jengelh@inai.de
- Use noun phrase in summary.
* Mon Aug 13 2018 cwh@suse.com
- Update to version 1.06.002
  + fixed export and import of .mat files containing beavers. Such files
    from JellyFish, Snowie and XG should import but not the flawed ones
    created by earlier versions of GNUbg (use .sgf files in this case).
    If exporting from GNUbg to other software, note that the latter may
    not support raccoons or further redoubles and may assume that beavers
    cannot be dropped.
  + due to different versions of the GTK graphical libraries, the look of
    the GUI is slightly different from that of the previous versions.
  + the minor version of the Python interpreter is different (major
    version is unchanged at 2.7). Python modules included with GNUbg may
    differ in more significant ways.
  Includes changes from 1.05.000:
  + upgrade of the random.org code to support https protocol
* Tue Jul 24 2018 bwiedemann@suse.com
- Disable CPU detection during compile time and assume SSE2 is available everywhere, but AVX is not (boo#1100677)
* Mon Apr 18 2016 dimstar@opensuse.org
- Remove local copy of glib-gettext.m4 in case we have one
  available on the system. It can't be older than what gnubg ships.
* Thu Jan 15 2015 p.drouand@gmail.com
- Update to version 1.04.001
  + play.c. external.c : Fix external interface bug that prevented
  external socket players from working. Fix bug that prevented
  external socket interface errors being displayed.
  https://savannah.gnu.org/bugs/?43747
- Split out language files in their own subpackage
- Make main package recommend gnubg-lang
* Tue Aug  5 2014 cwh@suse.com
- 1.03.000
- added recommends: python-MySQL-python
- removed patches docdir.patch and glu.patch since these things
  are now fixed upstream.
* Wed Sep 18 2013 cwh@suse.com
- Leaving tarball as gz
* Tue Aug 20 2013 cwh@suse.com
- (Re)Enabled 3d board by fixing GLU linking (oS!=12.3)
* Mon Aug 19 2013 cwh@suse.com
- Update to 1.02.000
- Improved performance (speed)
- Support for AVX(SIMD)
- Better Python support
- Stronger neural network
- Even/Odd ply effect reduced
- Some analysis options have been simplified
- Various miscellaneous bug fixes
* Mon Jul 29 2013 cwh@suse.com
- Updated to snapshot 20130725
* Mon Sep  3 2012 idonmez@suse.com
- Disable gtkglext-devel dependency for openSUSE > 12.2
* Thu Jul 19 2012 cwh@suse.com
- first try to make it building for Fedora 17
* Wed Jul 11 2012 cwh@suse.com
- updated to snapshot 20120711
- cleaned specfile
* Tue Mar  1 2011 cwh@novell.com
- updated to snapshot 20110301
* Tue Aug 17 2010 cwh@novell.com
- updated to snapshot 20100817
* Mon Aug  2 2010 cwh@novell.com
- updated to snapshot 20100802
* Tue Jun 22 2010 cwh@novell.com
- updated to snapshot 20100622
* Tue Jun 15 2010 cwh@novell.com
- let doc going to proper docdir
* Sat Jun 12 2010 cwh@novell.com
- moved desktop file out of the spec file
- updated to most recent svn snapshot
* Tue Jun  1 2010 cwh@novell.com
- imported patch from upstream:
  - made used libpngversion more flexible
  - better fix for buffer overflow
* Fri May 28 2010 cwh@novell.com
- added desktop file
- use libpng 1.4 for Factory (11.3)
- updated package description
* Fri May 21 2010 cwh@novell.com
- fixing fedora build (libpng version)
* Thu May 20 2010 cwh@novell.com
- fix building on >11.2 by requiring libpng less than 1.4
- wrap long BuildRequires
* Wed May 19 2010 cwh@novell.com
- fixed buffer overflow
- fixed filelist
- added debug packages
* Tue May 18 2010 cwh@novell.com
- updated to 0.9.0
- fixed specfile for openSUSE buildservice and current distributions
* Sat Nov 18 2006 ace@gnubg.org
- some slight changes in specfile
* Tue Dec 28 2004 ace@gnubg.org
- new weights including pruning
* Mon Oct 11 2004 ace@gnubg.org
- fixed some minor bugs
* Wed Sep  1 2004 ace@gnubg.org
- new rpms with 3d enabled
* Wed Nov  5 2003 ace@gnubg.org
- made the spec suit to redhat and suse <ace@gnubg.org>
- disabled 3d (still problems with nvidia)
- added gpg signature
* Thu Oct 23 2003 ace@gnubg.org
- disabled gdbm and guile
- changed info- and manpath
* Mon Oct 20 2003 ace@gnubg.org
- divided into three packages (gnubg, databases, sounds)
* Sat Oct 18 2003 ace@gnubg.org
- initial package (Version 0.14)
